@@ -29,10 +29,24 @@ def test_zenodo_convert():
         result = validate_codemeta(data)
         assert result == True
         zenodo = crosswalk(data, "codemeta", "Zenodo")
+        # This file has an incompatible license; should not be listed
+        assert "license" not in zenodo
         with open("tests/zenodo.json", "r") as compfile:
             comp = json.load(compfile)
             assert comp == zenodo
         # json.dump(codemeta,outfile)
+    with open("tests/codemeta_bigger.json") as infile:
+        data = json.load(infile)
+        result = validate_codemeta(data)
+        assert result == True
+        zenodo = crosswalk(data, "codemeta", "Zenodo")
+        # This file has a compatible license; should be listed
+        assert "license" in zenodo
+        with open("tests/zenodo_bigger.json", "r") as compfile:
+            comp = json.load(compfile)
+            print(comp)
+            print(zenodo)
+            assert comp == zenodo
 
 
 test_basic_convert()
